<?php

/*
		Généalogik
		
        Class for table : depot.

        07/03/2021 10:45

        lvardon@laposte.net - 2021
        
        Licence libre

        Usage examples :

        <?php

            include_once("classdir/dbconnect.php);
            include_once("classdir/class_depot.php);

            // Class instance
            $mydepot = depot( $db );

            // Select all reccords :
            $results = $mydepot->selectAll();
            foreach($results as $row) {
                print_r($row);
            } 

            // Select reccord #12 :
            $id = 12;
            $row = $mydepot->select($id);
            print_r($row);

        ?>

*/
class _depot {
      
    public $db;
    public $lasterror="";
    public $lastInsertId=-1;
    public $count = 0;
  
    /*
        Initialise object with dbHanler.
                
    */    
    function __construct( $db ) {
        $this->db = $db;
    }

    /*
        Select one reccord from depot.
        
        parameters : $id (reccord id).
        return : associative array of reccord.
    */
    function select($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.description as 'a.description',
			a.icon as 'a.icon',
			a.url as 'a.url',
			a.adress_1 as 'a.adress_1',
			a.adress_2 as 'a.adress_2',
			a.city as 'a.city',
			a.zip as 'a.zip',
			a.country as 'a.country'


		from depot a 

		where a.id = :id; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    function selectPrev($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.description as 'a.description',
			a.icon as 'a.icon',
			a.url as 'a.url',
			a.adress_1 as 'a.adress_1',
			a.adress_2 as 'a.adress_2',
			a.city as 'a.city',
			a.zip as 'a.zip',
			a.country as 'a.country'


		from depot a 

		where a.id =  (SELECT id FROM depot WHERE id < :id ORDER BY id DESC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }


    function selectNext($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.description as 'a.description',
			a.icon as 'a.icon',
			a.url as 'a.url',
			a.adress_1 as 'a.adress_1',
			a.adress_2 as 'a.adress_2',
			a.city as 'a.city',
			a.zip as 'a.zip',
			a.country as 'a.country'


		from depot a 

		where a.id =  (SELECT id FROM depot WHERE id > :id ORDER BY id ASC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    /*
        Select all reccords from depot  (with default order).
        
        parameters : None
        return : associative array of reccords.
    */
    function selectAll() {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.description as 'a.description',
			a.icon as 'a.icon',
			a.url as 'a.url',
			a.adress_1 as 'a.adress_1',
			a.adress_2 as 'a.adress_2',
			a.city as 'a.city',
			a.zip as 'a.zip',
			a.country as 'a.country'


		from depot a 

		;    
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

    /*
        Update depot 
        
        parameters : $id (reccord id) and fields list values.
        return : True if no error.
    */
    function update( $id, $name,$code,$description,$icon,$url,$adress_1,$adress_2,$city,$zip,$country ) {

        $this->lasterror="";        

		if ($name == '') $name = null;
		if ($code == '') $code = null;
		if ($description == '') $description = null;
		if ($icon == '') $icon = null;
		if ($url == '') $url = null;
		if ($adress_1 == '') $adress_1 = null;
		if ($adress_2 == '') $adress_2 = null;
		if ($city == '') $city = null;
		if ($zip == '') $zip = null;
		if ($country == '') $country = null;
		

        if ($this->checkValue( array( 
		$name => '',
		$code => '',
		$description => '',
		$icon => '',
		$url => '',
		$adress_1 => '',
		$adress_2 => '',
		$city => '',
		$zip => '',
		$country => ''

) ) == false )
        {
            $this->lasterror="Check fields false";        
            return false;
        }

        $sqlSt="
		update depot set
			name = :name,
			code = :code,
			description = :description,
			icon = :icon,
			url = :url,
			adress_1 = :adress_1,
			adress_2 = :adress_2,
			city = :city,
			zip = :zip,
			country = :country

		where id = :id; 
            ";

        try {        
            
            $stmt = $this->db->prepare($sqlSt);
            
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);

			$stmt->bindParam(':name', $name, PDO::PARAM_STR); 
			$stmt->bindParam(':code', $code, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
			$stmt->bindParam(':icon', $icon, PDO::PARAM_STR); 
			$stmt->bindParam(':url', $url, PDO::PARAM_STR); 
			$stmt->bindParam(':adress_1', $adress_1, PDO::PARAM_STR); 
			$stmt->bindParam(':adress_2', $adress_2, PDO::PARAM_STR); 
			$stmt->bindParam(':city', $city, PDO::PARAM_STR); 
			$stmt->bindParam(':zip', $zip, PDO::PARAM_STR); 
			$stmt->bindParam(':country', $country, PDO::PARAM_STR); 
 
            $stmt->execute();             
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql update '.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>description</b> = [$description],<b>icon</b> = [$icon],<b>url</b> = [$url],<b>adress_1</b> = [$adress_1],<b>adress_2</b> = [$adress_2],<b>city</b> = [$city],<b>zip</b> = [$zip],<b>country</b> = [$country]";
				
				return false;
			}   
			         
            return true;

        } catch (Exception $e) {            
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>description</b> = [$description],<b>icon</b> = [$icon],<b>url</b> = [$url],<b>adress_1</b> = [$adress_1],<b>adress_2</b> = [$adress_2],<b>city</b> = [$city],<b>zip</b> = [$zip],<b>country</b> = [$country]";  
            return false;
        }

    }

    /*
        Insert new reccord into depot.
        
        Parameters : fields values list.
        return : True if no error.
    */
    function insert( $name,$code,$description,$icon,$url,$adress_1,$adress_2,$city,$zip,$country ) {

        $this->lasterror="";
        $this->lastInsertId = -1;

		if ($name == '') $name = null;
		if ($code == '') $code = null;
		if ($description == '') $description = null;
		if ($icon == '') $icon = null;
		if ($url == '') $url = null;
		if ($adress_1 == '') $adress_1 = null;
		if ($adress_2 == '') $adress_2 = null;
		if ($city == '') $city = null;
		if ($zip == '') $zip = null;
		if ($country == '') $country = null;
		
		
        if ($this->checkValue( array( 
		$name => '',
		$code => '',
		$description => '',
		$icon => '',
		$url => '',
		$adress_1 => '',
		$adress_2 => '',
		$city => '',
		$zip => '',
		$country => ''

) ) == false )
        {
            $this->lasterror="Check fields error";        
            return false;
        }

        $sqlSt="
		insert into depot (
		name,
		code,
		description,
		icon,
		url,
		adress_1,
		adress_2,
		city,
		zip,
		country
 
			)
		values (
		:name, 
		:code, 
		:description, 
		:icon, 
		:url, 
		:adress_1, 
		:adress_2, 
		:city, 
		:zip, 
		:country 
 
			);    
            ";

        try {        

            $stmt = $this->db->prepare($sqlSt);               
			
			$stmt->bindParam(':name', $name, PDO::PARAM_STR); 
			$stmt->bindParam(':code', $code, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
			$stmt->bindParam(':icon', $icon, PDO::PARAM_STR); 
			$stmt->bindParam(':url', $url, PDO::PARAM_STR); 
			$stmt->bindParam(':adress_1', $adress_1, PDO::PARAM_STR); 
			$stmt->bindParam(':adress_2', $adress_2, PDO::PARAM_STR); 
			$stmt->bindParam(':city', $city, PDO::PARAM_STR); 
			$stmt->bindParam(':zip', $zip, PDO::PARAM_STR); 
			$stmt->bindParam(':country', $country, PDO::PARAM_STR); 
 

            $stmt->execute();     
            $this->lastInsertId = $this->db->lastInsertId(); 
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql insert'.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>description</b> = [$description],<b>icon</b> = [$icon],<b>url</b> = [$url],<b>adress_1</b> = [$adress_1],<b>adress_2</b> = [$adress_2],<b>city</b> = [$city],<b>zip</b> = [$zip],<b>country</b> = [$country]";
				return false;
			}              
                   
            return true;

        } catch (Exception $e) {
             $this->lasterror = $e->getMessage().'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>description</b> = [$description],<b>icon</b> = [$icon],<b>url</b> = [$url],<b>adress_1</b> = [$adress_1],<b>adress_2</b> = [$adress_2],<b>city</b> = [$city],<b>zip</b> = [$zip],<b>country</b> = [$country]";
            return false;
        }
    }

    /*
        Delete one reccord from depot.
        
        parameters : $id (reccord id).
        return : True if no error.
    */
    function delete($id) {

        $this->lasterror="";

        $sqlSt="
		delete from depot             
		where id = :id; 
            ";   
     
        try {        

            $stmt = $this->db->prepare($sqlSt);  
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();        
            
			if ($stmt->rowCount() == 0) {
				$this->lasterror = "Erreur Sql delete ".' (<b>Id</b> ='.$id.')';       
				return false;
			}              

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b>='.$id.')';
            return false;
        }
        return true;
    }

    /*
        Get id min, id max, record count from depot  
        
        parameters : None
        return : count value or False in case of error
    */
	function getCount() {
		
        $this->lasterror="";

        $sqlSt="
		select min(id) as minid, max(id) as maxid, count(*) as count 
		from depot 
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC); 
            return $results[0];          

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            return array( 'minid' => -1, 'maxid' => -1, 'count' => -1);
        }
        		
		//return $this->count;
		return $results[0];
	}




	public $colmeta = [
	'a.id' => array (
		'metades' => "Identifiant dépôt",
		'sortformat' => "{{sortformat}}",
		'listlen' => 6,
		'listlib' => 'id',
		'listlink' => 'on',
		'selectlen' => 0,
		'selectlib' => 'Selection',
		'selectlink' => 'on',
		'selectdisplay' => '',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => '', 
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 

		),
	'a.name' => array ( 
		'metades' => "Nom du dépôt",
		'sortformat' => "", 
		'listlen' => 45,
		'listlib' => 'Nom' , 
		'listlink' => '',
		'selectlen' => 45,
		'selectlib' => 'a.name' , 
		'selectlink' => 'on',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.code' => array ( 
		'metades' => "Code, identifiant du dépôt",
		'sortformat' => "", 
		'listlen' => 4,
		'listlib' => 'Code' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'Code' , 
		'selectlink' => '',
		'selectdisplay' => 'color',
		'selectdisplaywidth' => '50', 
		'selectdisplayheight' => '50', 
		'listdisplay' => 'color',
		'listdisplaywidth' => '50', 
		'listdisplayheight' => '50' 
),
	'a.description' => array ( 
		'metades' => "Description",
		'sortformat' => "", 
		'listlen' => 20,
		'listlib' => 'Description' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'a_description' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.icon' => array ( 
		'metades' => "Icone associé à ce dépôt",
		'sortformat' => "", 
		'listlen' => 20,
		'listlib' => 'icone' , 
		'listlink' => '',
		'selectlen' => 20,
		'selectlib' => 'icone' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'urlpic',
		'listdisplaywidth' => '50', 
		'listdisplayheight' => '50' 
),
	'a.url' => array ( 
		'metades' => "Adresse web du dépôt",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'Url' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'a_url' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'url',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.adress_1' => array ( 
		'metades' => "Adresse du dépôt",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'adresse' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'adresse' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.adress_2' => array ( 
		'metades' => "Seconde ligne de l adresse du dépôt",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'adresse (suite)' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'adresse (suite)' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.city' => array ( 
		'metades' => "Ville",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'Ville' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'Ville' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.zip' => array ( 
		'metades' => "Code Postal",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'Code Postal' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'Code Postal' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.country' => array ( 
		'metades' => "Pays",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'Pays' , 
		'listlink' => 'on',
		'selectlen' => 0,
		'selectlib' => 'Pays' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
)

			
	];

    /*
        Get field property value
        
        Parameters : field name and property name.
        return : value of property.
    */

	function getMeta( $fieldkey , $metakey ) {
		return $this->colmeta [$fieldkey][$metakey];
	}

    /*
        Get labels for list table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderList() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['listlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['listlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenList( $field ) {		
		
		return $this->colmeta[$field]['listlen'];
	}

	function getTableFieldLinkList( $field ) {		
		
		return $this->colmeta[$field]['listlink'];
	}

    /*
        Get labels for select table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderSelect() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['selectlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['selectlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlen'];
	}

	function getTableFieldLinkSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlink'];
	}

	
    /*
        Check user input values for depot.
        
        Parameters : array of fields with regexp  paterns. ex: array( $nom =>'^(?!\s*$).+' , $icone => '')
        return : False if at last one regexp does not match.
    */
    function checkValue( $arrayCheck ) {

        $indexfield=1;
        foreach ( $arrayCheck as $value => $pattern) {

            if ($pattern=='') continue;

            $pattern='/'.$pattern.'/';

            if (!preg_match($pattern, $value)) {
                $this->lasterror = "Erreur champ #".$indexfield. '. Valeur:['.$value.']';
                return false;                
            }

            $indexfield+=1;

        }

        return true;
    }

} // end class

?>
