<?php

/*
		Généalogik
		
        Class for table : person.

        07/03/2021 10:45

        lvardon@laposte.net - 2021
        
        Licence libre

        Usage examples :

        <?php

            include_once("classdir/dbconnect.php);
            include_once("classdir/class_person.php);

            // Class instance
            $myperson = person( $db );

            // Select all reccords :
            $results = $myperson->selectAll();
            foreach($results as $row) {
                print_r($row);
            } 

            // Select reccord #12 :
            $id = 12;
            $row = $myperson->select($id);
            print_r($row);

        ?>

*/
class _person {
      
    public $db;
    public $lasterror="";
    public $lastInsertId=-1;
    public $count = 0;
  
    /*
        Initialise object with dbHanler.
                
    */    
    function __construct( $db ) {
        $this->db = $db;
    }

    /*
        Select one reccord from person.
        
        parameters : $id (reccord id).
        return : associative array of reccord.
    */
    function select($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.displayname as 'a.displayname',
			a.description as 'a.description',
			a.firstname as 'a.firstname',
			a.lastname as 'a.lastname',
			a.private as 'a.private',
			a.icon as 'a.icon',
			a.sex as 'a.sex',
			a.notesearch as 'a.notesearch',
			a.firstnameprefix as 'a.firstnameprefix',
			a.displaynameprefix as 'a.displaynameprefix',
			a.lastnamesuffix as 'a.lastnamesuffix',
			a.surname as 'a.surname',
			a.datecreated as 'a.datecreated'


		from person a 

		where a.id = :id; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    function selectPrev($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.displayname as 'a.displayname',
			a.description as 'a.description',
			a.firstname as 'a.firstname',
			a.lastname as 'a.lastname',
			a.private as 'a.private',
			a.icon as 'a.icon',
			a.sex as 'a.sex',
			a.notesearch as 'a.notesearch',
			a.firstnameprefix as 'a.firstnameprefix',
			a.displaynameprefix as 'a.displaynameprefix',
			a.lastnamesuffix as 'a.lastnamesuffix',
			a.surname as 'a.surname',
			a.datecreated as 'a.datecreated'


		from person a 

		where a.id =  (SELECT id FROM person WHERE id < :id ORDER BY id DESC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }


    function selectNext($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.displayname as 'a.displayname',
			a.description as 'a.description',
			a.firstname as 'a.firstname',
			a.lastname as 'a.lastname',
			a.private as 'a.private',
			a.icon as 'a.icon',
			a.sex as 'a.sex',
			a.notesearch as 'a.notesearch',
			a.firstnameprefix as 'a.firstnameprefix',
			a.displaynameprefix as 'a.displaynameprefix',
			a.lastnamesuffix as 'a.lastnamesuffix',
			a.surname as 'a.surname',
			a.datecreated as 'a.datecreated'


		from person a 

		where a.id =  (SELECT id FROM person WHERE id > :id ORDER BY id ASC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    /*
        Select all reccords from person  (with default order).
        
        parameters : None
        return : associative array of reccords.
    */
    function selectAll() {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.displayname as 'a.displayname',
			a.description as 'a.description',
			a.firstname as 'a.firstname',
			a.lastname as 'a.lastname',
			a.private as 'a.private',
			a.icon as 'a.icon',
			a.sex as 'a.sex',
			a.notesearch as 'a.notesearch',
			a.firstnameprefix as 'a.firstnameprefix',
			a.displaynameprefix as 'a.displaynameprefix',
			a.lastnamesuffix as 'a.lastnamesuffix',
			a.surname as 'a.surname',
			a.datecreated as 'a.datecreated'


		from person a 

		;    
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

    /*
        Update person 
        
        parameters : $id (reccord id) and fields list values.
        return : True if no error.
    */
    function update( $id, $displayname,$description,$firstname,$lastname,$private,$icon,$sex,$notesearch,$firstnameprefix,$displaynameprefix,$lastnamesuffix,$surname,$datecreated ) {

        $this->lasterror="";        

		if ($displayname == '') $displayname = null;
		if ($description == '') $description = null;
		if ($firstname == '') $firstname = null;
		if ($lastname == '') $lastname = null;
		if ($private == '') $private = null;
		if ($icon == '') $icon = null;
		if ($sex == '') $sex = null;
		if ($notesearch == '') $notesearch = null;
		if ($firstnameprefix == '') $firstnameprefix = null;
		if ($displaynameprefix == '') $displaynameprefix = null;
		if ($lastnamesuffix == '') $lastnamesuffix = null;
		if ($surname == '') $surname = null;
		if ($datecreated == '') $datecreated = null;
		

        if ($this->checkValue( array( 
		$displayname => '',
		$description => '',
		$firstname => '',
		$lastname => '',
		$private => '',
		$icon => '',
		$sex => '',
		$notesearch => '',
		$firstnameprefix => '',
		$displaynameprefix => '',
		$lastnamesuffix => '',
		$surname => '',
		$datecreated => ''

) ) == false )
        {
            $this->lasterror="Check fields false";        
            return false;
        }

        $sqlSt="
		update person set
			displayname = :displayname,
			description = :description,
			firstname = :firstname,
			lastname = :lastname,
			private = :private,
			icon = :icon,
			sex = :sex,
			notesearch = :notesearch,
			firstnameprefix = :firstnameprefix,
			displaynameprefix = :displaynameprefix,
			lastnamesuffix = :lastnamesuffix,
			surname = :surname,
			datecreated = :datecreated

		where id = :id; 
            ";

        try {        
            
            $stmt = $this->db->prepare($sqlSt);
            
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);

			$stmt->bindParam(':displayname', $displayname, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
			$stmt->bindParam(':firstname', $firstname, PDO::PARAM_STR); 
			$stmt->bindParam(':lastname', $lastname, PDO::PARAM_STR); 
			$stmt->bindParam(':private', $private, PDO::PARAM_INT); 
			$stmt->bindParam(':icon', $icon, PDO::PARAM_STR); 
			$stmt->bindParam(':sex', $sex, PDO::PARAM_STR); 
			$stmt->bindParam(':notesearch', $notesearch, PDO::PARAM_STR); 
			$stmt->bindParam(':firstnameprefix', $firstnameprefix, PDO::PARAM_STR); 
			$stmt->bindParam(':displaynameprefix', $displaynameprefix, PDO::PARAM_STR); 
			$stmt->bindParam(':lastnamesuffix', $lastnamesuffix, PDO::PARAM_STR); 
			$stmt->bindParam(':surname', $surname, PDO::PARAM_STR); 
			$stmt->bindParam(':datecreated', $datecreated, PDO::PARAM_STR); 
 
            $stmt->execute();             
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql update '.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>displayname</b> = [$displayname],<b>description</b> = [$description],<b>firstname</b> = [$firstname],<b>lastname</b> = [$lastname],<b>private</b> = [$private],<b>icon</b> = [$icon],<b>sex</b> = [$sex],<b>notesearch</b> = [$notesearch],<b>firstnameprefix</b> = [$firstnameprefix],<b>displaynameprefix</b> = [$displaynameprefix],<b>lastnamesuffix</b> = [$lastnamesuffix],<b>surname</b> = [$surname],<b>datecreated</b> = [$datecreated]";
				
				return false;
			}   
			         
            return true;

        } catch (Exception $e) {            
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>displayname</b> = [$displayname],<b>description</b> = [$description],<b>firstname</b> = [$firstname],<b>lastname</b> = [$lastname],<b>private</b> = [$private],<b>icon</b> = [$icon],<b>sex</b> = [$sex],<b>notesearch</b> = [$notesearch],<b>firstnameprefix</b> = [$firstnameprefix],<b>displaynameprefix</b> = [$displaynameprefix],<b>lastnamesuffix</b> = [$lastnamesuffix],<b>surname</b> = [$surname],<b>datecreated</b> = [$datecreated]";  
            return false;
        }

    }

    /*
        Insert new reccord into person.
        
        Parameters : fields values list.
        return : True if no error.
    */
    function insert( $displayname,$description,$firstname,$lastname,$private,$icon,$sex,$notesearch,$firstnameprefix,$displaynameprefix,$lastnamesuffix,$surname,$datecreated ) {

        $this->lasterror="";
        $this->lastInsertId = -1;

		if ($displayname == '') $displayname = null;
		if ($description == '') $description = null;
		if ($firstname == '') $firstname = null;
		if ($lastname == '') $lastname = null;
		if ($private == '') $private = null;
		if ($icon == '') $icon = null;
		if ($sex == '') $sex = null;
		if ($notesearch == '') $notesearch = null;
		if ($firstnameprefix == '') $firstnameprefix = null;
		if ($displaynameprefix == '') $displaynameprefix = null;
		if ($lastnamesuffix == '') $lastnamesuffix = null;
		if ($surname == '') $surname = null;
		if ($datecreated == '') $datecreated = null;
		
		
        if ($this->checkValue( array( 
		$displayname => '',
		$description => '',
		$firstname => '',
		$lastname => '',
		$private => '',
		$icon => '',
		$sex => '',
		$notesearch => '',
		$firstnameprefix => '',
		$displaynameprefix => '',
		$lastnamesuffix => '',
		$surname => '',
		$datecreated => ''

) ) == false )
        {
            $this->lasterror="Check fields error";        
            return false;
        }

        $sqlSt="
		insert into person (
		displayname,
		description,
		firstname,
		lastname,
		private,
		icon,
		sex,
		notesearch,
		firstnameprefix,
		displaynameprefix,
		lastnamesuffix,
		surname,
		datecreated
 
			)
		values (
		:displayname, 
		:description, 
		:firstname, 
		:lastname, 
		:private, 
		:icon, 
		:sex, 
		:notesearch, 
		:firstnameprefix, 
		:displaynameprefix, 
		:lastnamesuffix, 
		:surname, 
		:datecreated 
 
			);    
            ";

        try {        

            $stmt = $this->db->prepare($sqlSt);               
			
			$stmt->bindParam(':displayname', $displayname, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
			$stmt->bindParam(':firstname', $firstname, PDO::PARAM_STR); 
			$stmt->bindParam(':lastname', $lastname, PDO::PARAM_STR); 
			$stmt->bindParam(':private', $private, PDO::PARAM_INT); 
			$stmt->bindParam(':icon', $icon, PDO::PARAM_STR); 
			$stmt->bindParam(':sex', $sex, PDO::PARAM_STR); 
			$stmt->bindParam(':notesearch', $notesearch, PDO::PARAM_STR); 
			$stmt->bindParam(':firstnameprefix', $firstnameprefix, PDO::PARAM_STR); 
			$stmt->bindParam(':displaynameprefix', $displaynameprefix, PDO::PARAM_STR); 
			$stmt->bindParam(':lastnamesuffix', $lastnamesuffix, PDO::PARAM_STR); 
			$stmt->bindParam(':surname', $surname, PDO::PARAM_STR); 
			$stmt->bindParam(':datecreated', $datecreated, PDO::PARAM_STR); 
 

            $stmt->execute();     
            $this->lastInsertId = $this->db->lastInsertId(); 
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql insert'.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>displayname</b> = [$displayname],<b>description</b> = [$description],<b>firstname</b> = [$firstname],<b>lastname</b> = [$lastname],<b>private</b> = [$private],<b>icon</b> = [$icon],<b>sex</b> = [$sex],<b>notesearch</b> = [$notesearch],<b>firstnameprefix</b> = [$firstnameprefix],<b>displaynameprefix</b> = [$displaynameprefix],<b>lastnamesuffix</b> = [$lastnamesuffix],<b>surname</b> = [$surname],<b>datecreated</b> = [$datecreated]";
				return false;
			}              
                   
            return true;

        } catch (Exception $e) {
             $this->lasterror = $e->getMessage().'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>displayname</b> = [$displayname],<b>description</b> = [$description],<b>firstname</b> = [$firstname],<b>lastname</b> = [$lastname],<b>private</b> = [$private],<b>icon</b> = [$icon],<b>sex</b> = [$sex],<b>notesearch</b> = [$notesearch],<b>firstnameprefix</b> = [$firstnameprefix],<b>displaynameprefix</b> = [$displaynameprefix],<b>lastnamesuffix</b> = [$lastnamesuffix],<b>surname</b> = [$surname],<b>datecreated</b> = [$datecreated]";
            return false;
        }
    }

    /*
        Delete one reccord from person.
        
        parameters : $id (reccord id).
        return : True if no error.
    */
    function delete($id) {

        $this->lasterror="";

        $sqlSt="
		delete from person             
		where id = :id; 
            ";   
     
        try {        

            $stmt = $this->db->prepare($sqlSt);  
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();        
            
			if ($stmt->rowCount() == 0) {
				$this->lasterror = "Erreur Sql delete ".' (<b>Id</b> ='.$id.')';       
				return false;
			}              

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b>='.$id.')';
            return false;
        }
        return true;
    }

    /*
        Get id min, id max, record count from person  
        
        parameters : None
        return : count value or False in case of error
    */
	function getCount() {
		
        $this->lasterror="";

        $sqlSt="
		select min(id) as minid, max(id) as maxid, count(*) as count 
		from person 
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC); 
            return $results[0];          

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            return array( 'minid' => -1, 'maxid' => -1, 'count' => -1);
        }
        		
		//return $this->count;
		return $results[0];
	}




	public $colmeta = [
	'a.id' => array (
		'metades' => "id",
		'sortformat' => "{{sortformat}}",
		'listlen' => 4,
		'listlib' => 'id',
		'listlink' => 'on',
		'selectlen' => 4,
		'selectlib' => 'id',
		'selectlink' => 'on',
		'selectdisplay' => '',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => '', 
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 

		),
	'a.displayname' => array ( 
		'metades' => "displayname",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'displayname' , 
		'listlink' => '',
		'selectlen' => 25,
		'selectlib' => 'displayname' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.description' => array ( 
		'metades' => "description",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'description' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'description' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.firstname' => array ( 
		'metades' => "firstname",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'firstname' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'firstname' , 
		'selectlink' => 'on',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.lastname' => array ( 
		'metades' => "lastname",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'lastname' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'lastname' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.private' => array ( 
		'metades' => "private",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'private' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'private' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.icon' => array ( 
		'metades' => "icon",
		'sortformat' => "", 
		'listlen' => 4,
		'listlib' => 'icon' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'icon' , 
		'selectlink' => '',
		'selectdisplay' => 'urlpic',
		'selectdisplaywidth' => '50', 
		'selectdisplayheight' => '50', 
		'listdisplay' => 'urlpic',
		'listdisplaywidth' => '50', 
		'listdisplayheight' => '50' 
),
	'a.sex' => array ( 
		'metades' => "sex",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'sex' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'sex' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.notesearch' => array ( 
		'metades' => "Notes de recherche",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'Notes de recherche' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'Notes de recherche' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.firstnameprefix' => array ( 
		'metades' => "firstnameprefix",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'firstnameprefix' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'firstnameprefix' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.displaynameprefix' => array ( 
		'metades' => "displaynameprefix",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'displaynameprefix' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'displaynameprefix' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.lastnamesuffix' => array ( 
		'metades' => "lastnamesuffix",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'lastnamesuffix' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'lastnamesuffix' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.surname' => array ( 
		'metades' => "surname",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'surname' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'surname' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.datecreated' => array ( 
		'metades' => "datecreated",
		'sortformat' => "date", 
		'listlen' => 10,
		'listlib' => 'datecreated' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'datecreated' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
)

			
	];

    /*
        Get field property value
        
        Parameters : field name and property name.
        return : value of property.
    */

	function getMeta( $fieldkey , $metakey ) {
		return $this->colmeta [$fieldkey][$metakey];
	}

    /*
        Get labels for list table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderList() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['listlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['listlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenList( $field ) {		
		
		return $this->colmeta[$field]['listlen'];
	}

	function getTableFieldLinkList( $field ) {		
		
		return $this->colmeta[$field]['listlink'];
	}

    /*
        Get labels for select table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderSelect() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['selectlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['selectlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlen'];
	}

	function getTableFieldLinkSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlink'];
	}

	
    /*
        Check user input values for person.
        
        Parameters : array of fields with regexp  paterns. ex: array( $nom =>'^(?!\s*$).+' , $icone => '')
        return : False if at last one regexp does not match.
    */
    function checkValue( $arrayCheck ) {

        $indexfield=1;
        foreach ( $arrayCheck as $value => $pattern) {

            if ($pattern=='') continue;

            $pattern='/'.$pattern.'/';

            if (!preg_match($pattern, $value)) {
                $this->lasterror = "Erreur champ #".$indexfield. '. Valeur:['.$value.']';
                return false;                
            }

            $indexfield+=1;

        }

        return true;
    }

} // end class

?>
