<?php

/*
	{{title}}
	
	Export GEDCOM
	
	{{author}}
	
	{{licence}}
	
	{{datetime}}

*/

/*
 * http://fauque.fr/gedcom.php
 * 
 * 
 * 
 * 
 * Ajouts tag
 * http://www.francegenweb.org/wiki/index.php?title=Contenu_d%27un_fichier_(gedcom)#Enregistrement_d.27un_objet_.27media.27
 * 
 * https://docs.ancestris.org/books/mode-demploi/page/documenter-vos-sources
Étiquette QUAY
0 =source non fiable ou estimation  
1 =fiabilité douteuse  
2 =source indirecte  
3 =preuve indiscutable 
* 
* La page dans la source - Étiquette PAGE 
* 
* La retranscription du texte de la source - Étiquettes DATA puis TEXT
Les liens vers les fichiers multimédia - Étiquette OBJE 
Le type d'événement cité dans la source (peut être différent de l'événement de l'individu auquel elle est rattachée) - Étiquette EVEN 
* 
 * 
 * CONC CONT
https://www.tamurajones.net/GEDCOMCONCAndCONT.xhtml

https://chronoplexsoftware.com/gedcomvalidator/help/W462.htm
Long line values which support line breaks should be wrapped using concatenation ('CONC') tags and continuation ('CONT') tags so that the maximum length of the first part of the line value does not exceed the length specified for that field.
In all cases the length of GEDCOM lines must not exceed 255 characters.

 
Période dates
* https://genopresse.com/blog/2011/03/lentree-des-dates-en-genealogie/ 
 

http://www.francegenweb.org/wiki/index.php?title=Grammaire_(gedcom)

* 
 */



include_once "dbconnect.php";


class gedcomParser {
      
    public $db;
    public $lasterror="";
    public $lastInsertId=-1;
    public $count = 0;
   
    function __construct( $db ) {
        $this->db = $db;
    }

	function dumpError() {	
		echo 'ERREUR : '.$this->lasterror;
		echo "\n";
	}

    function selectMeta($code) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.code as 'a.code',
			a.name as 'a.name',
			a.value as 'a.value',
			a.type as 'a.type',
			a.description as 'a.description'


		from metadata a 

		where a.code = :code; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':code', $code, PDO::PARAM_STR);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            
            return $results[0]['a.value'];

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (code='.$code.')';
            return false;
        }
    }

	function selectAllINDI() {

        $this->lasterror='';

        $sqlSt="
select p.id as 'id', 
datecreated, 
p.lastname as 'lastname',  -- nom de famille
p.firstname as 'givenname', -- Prénom 
p.displayname as 'name',  -- Un mot ou une combinaison de mots utilisés pour aider à identifier un individu. Pour les femmes mariées, il s'agit du nom de jeune fille. Plus d'une ligne NOM devrait être utilisée pour les gens qui sont connus sous différents noms.
p.firstnameprefix,
p.lastnamesuffix,
p.surname,
p.firstname || ',' || p.lastname as 'name2' ,
p.sex as 'sex'
from person p
order by p.lastname 			";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }
   
	function selectIndiFAMS( $person_id ) {

        $this->lasterror='';

        $sqlSt="
select
e.id,
et.code,
e.date_begin as 'date',
e.name,
p1.id as 'wid',
p1.displayname as 'Mere',
p2.id as 'hid',
p2.displayname as 'Pere'
from event e , eventtype et
left outer join person p1 on p1.id = e.person_1_id
left outer join person p2 on p2.id = e.person_2_id
where et.id = e.eventtype_id
and (p1.id = $person_id or p2.id = $person_id)
and e.eventtype_id in (select et.id from Eventtype et where et.code in( 'MARR' , 'UNION'))       
";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results[0]['id'];

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }
      
	function selectIndiParents( $person_id ) {

        $this->lasterror='';

        $sqlSt="
select 
e.person_1_id,
p1.displayname,
y.name as event_type_name,
e.date_begin as event_date,
e.person_2_id,
p2.displayname as Mère,
e.person_3_id,
p3.displayname as Père,
pl.name as place_name
from 
event e,
person p1,
eventtype y
left outer join person p2 on e.person_2_id = p2.id 
left outer join person p3 on e.person_3_id = p3.id 
left outer join place pl on pl.id = e.place_id 
where y.id = e.eventtype_id
and e.person_1_id = p1.id 
and e.eventtype_id = (select et.id from Eventtype et where et.code in( 'BIRT', 'ADOP' ))   
and e.person_1_id = $person_id 
order by e.date_begin
     
";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }
   
    function selectIndiEventPlace( $person_id, $event_code ) {

        $this->lasterror='';

        $sqlSt="
	select p.id as 'id', p.city || ',' || ifnull(', ' || p.zipcode,'') || ',' || p.country as 'plac',
	p.gpslat, p.gpslon	
	from event e, place p
	where 
	e.place_id = p.id
	and e.person_1_id =  $person_id 
	and e.eventtype_id = ( select et.id from Eventtype  et where et.code = '$event_code' )";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results[0];

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }
       
	function selectIndiEventDate( $person_id ) {

        $this->lasterror='';

		$sqlSt = "
	select e.id as 'id', et.code, e.date_begin as 'date_begin'
	from event e , eventtype et	
	where 
		e.eventtype_id = et.id
	and et.category = 'INDI'
	and e.person_1_id = $person_id		
		";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            //return array ( 'date_begin' => $results[0]['date_begin'], 'hour_begin' => $results[0]['hour_begin']);
            return $results;
		} 
		catch (Exception $e) {
			$this->lasterror = $e->getMessage();
			$this->dumpError();            
            $this->count = 0;
            return false;
        }
    }    

	function selectEventDate( $event_id, $event_code ) {

        $this->lasterror='';

        $sqlSt="
	select e.id as 'id', e.date_begin as 'date_begin' 
	from event e 
	where	
	e.id = $event_id
	and e.eventtype_id = ( select et.id from Eventtype  et where et.code = '$event_code' )
		";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return array ( 'date_begin' => $results[0]['date_begin']);
		} 
		catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }    
	
    function selectEventPlace( $event_id, $event_code ) {

        $this->lasterror='';

        $sqlSt="
	select p.id as 'id', p.city || ',' || ifnull(', ' || p.zipcode,'') || ',' || p.country as 'plac',
	p.gpslat, p.gpslon
	from event e, place p
	where 
	e.place_id  = p.id
	and e.id =  $event_id 
	and e.eventtype_id = ( select et.id from Eventtype  et where et.code = '$event_code' )
	";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results[0];

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

    function selectEventSource( $event_id ) {

        $this->lasterror='';

        $sqlSt="
select 
s.id as 'id', 
s.quality  as 'quality',
s.datecreated as 'date_created', 
s.name as 'name', 
s.page as 'page', 
s.citation as 'citation', 
s.description,
s.quality as 'quality',
d.id as 'document_id',
d.name as 'document_name',
e.id as 'envent_id', 
e.name as 'event_name'
from event e, event_source es, source s
left outer join document d on d.id = es.document_id
where e.id = es.event_id 
and s.id = es.source_id
and e.id = '$event_id' 
	";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->dumpError();
            $this->count = 0;
            return false;
        }
    }
	
	function selectAllFAM( $event_category ) {

        $this->lasterror='';

        $sqlSt="
select
e.id,
e.datecreated,
et.code,
e.date_begin as 'date',
e.name,
p1.id as 'wid',
p1.displayname as 'Mere',
p2.id as 'hid',
p2.displayname as 'Pere'
from event e , eventtype et
left outer join person p1 on p1.id = e.person_1_id
left outer join person p2 on p2.id = e.person_2_id
where et.id = e.eventtype_id
and et.category = '$event_category'
";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

	function selectAllFAM1( $event_category , $person_id ) {

        $this->lasterror='';

        $sqlSt="
select
e.id,
e.datecreated,
et.code,
e.date_begin as 'date',
e.name,
p1.id as 'wid',
p1.displayname as 'Mere',
p2.id as 'hid',
p2.displayname as 'Pere'
from event e , eventtype et
left outer join person p1 on p1.id = e.person_1_id
left outer join person p2 on p2.id = e.person_2_id
where et.id = e.eventtype_id
and ( p1.id = $person_id or p2.id = $person_id)
and et.category = '$event_category'
";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

	function selectFAMCHILD( $person_id ) {

        $this->lasterror='';

        $sqlSt="
select 
e.person_1_id as 'id',
p1.displayname,
y.name as event_type_name,
e.date_begin as event_date,
e.person_2_id,
p2.displayname as Mère,
e.person_3_id,
p3.displayname as Père,
pl.name as place_name
from 
event e,
person p1,
eventtype y
left outer join person p2 on e.person_2_id = p2.id 
left outer join person p3 on e.person_3_id = p3.id 
left outer join place pl on pl.id = e.place_id 
where y.id = e.eventtype_id
and e.person_1_id = p1.id 
and e.eventtype_id in (select et.id from Eventtype et where et.code in ('BIRT', 'ADOP') )   
and ( e.person_3_id = $person_id or e.person_2_id = $person_id) -- Chercher père ou mère
order by e.date_begin       
";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

	function selectAllSOURCE() {

        $this->lasterror='';

        $sqlSt="
select 
s.id as 'id', s.datecreated, s.name as 'name', 
s.description,
s.quality as 'quality',
d.id as document_id,
d.name as document_name,
p.id as depot_id,
p.name as depot_name
from source s 
left outer join event_source es on  es.source_id = s.id 
left outer join document d on d.id = es.document_id
left outer join depot p on p.id = d.depot_id
			";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }
   
	function selectAllREPO() {

        $this->lasterror='';

        $sqlSt="
select d.id as 'id' , d.code, d.name as 'name', d.city, d.adress_1, d.adress_2, d.zip, d.country
from depot d
			";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }
   

	function selectAllOBJ() {

        $this->lasterror='';

        $sqlSt="
select 
d.id as 'id', d.name as 'name',
d.description as 'description' , 
d.url as 'url',
t.code
from document d, Documenttype t
where d.documenttype_id = t.id
			";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

} // end gedcomParser class ---------------------------------------------------

// CONT :
//https://www.tamurajones.net/GEDCOMCONCAndCONT.xhtml

// Sources :
//https://tmg.reigelridge.com/Sources-exporting.htm
//https://wiki.phpgedview.net/en/index.php/Proper_use_of_sources

//http://ged-inline.elasticbeanstalk.com/validate


// Synthèse : 
// http://www.tcgr.bufton.org/tcgpgedc.htm

$outLineNumber = 1;

function echoGedcom( $fp, $debugMode, $gedcomLevel, $id, $gedcomTag, $gedcomData ) {

	global $outLineNumber; 
 
	$gedcomColors = array(
	'linenumber' => '#ff33cc',
	'level' => '#db4dff',
	'id' => '#0020C2',
	'tag' => '#C35817',
	'data' => '#347C2C'
	);

	echo '<tr>';
	
	echo '<td>';
	echo '<span style="color:'.$gedcomColors['linenumber'].'">';  
	echo '['.$outLineNumber.']';
	$outLineNumber = $outLineNumber + 1;
	echo '</span>';
	echo '</td>';	
	
	echo '<td>';
	if ($gedcomLevel !== null) {
		echo '<span style="color:'.$gedcomColors['level'].'">';  
		echo $gedcomLevel;
		echo '</span>';	
		fwrite($fp, $gedcomLevel);
	}
	echo '</td>';

	
	echo '<td>';
	if ($id !== null) {
		echo '<span style="color:'.$gedcomColors['id'].'">';  
		echo $id;
		echo '</span>';			
		fwrite($fp, " ");		
		fwrite($fp, $id);	
	}
	echo '</td>';		

	echo '<td>';	
	for ($i = $gedcomLevel; $i >0; $i=$i-1) 
	{
		echo '&nbsp;&nbsp;';
	}

	if ($gedcomTag !== null) {
		echo '<span style="color:'.$gedcomColors['tag'].'">';  
		echo $gedcomTag;
		echo '</span>';	
		fwrite($fp, " ");				
		fwrite($fp, $gedcomTag);	
	}
	
	echo '&nbsp;';

	if ($gedcomData !== null) {
		echo '<span style="color:'.$gedcomColors['data'].'">';  
		fwrite($fp, " ");	
		echo '</span>';	
		echo $gedcomData;
		fwrite($fp, $gedcomData);		
	}
	echo '</td>';
	
	fwrite($fp, "\n");	
	
	echo '</tr>';
}

// DB : 08/09/1888 16:42
// return : 9 AUG 1642

function formatDate( $indate ) {
	$months = array(
		'', 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC'
	);

	$indatechunks = explode(" ", $indate); 
	
	$datechunks = explode("/", $indatechunks[0]); 
	
	return ( $datechunks[0].' '.$months[(int)($datechunks[1])*1].' '.$datechunks[2]);
}
function formatDateTime( $indate ) {
	$months = array(
		'', 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC'
	);

	$indatechunks = explode(" ", $indate); 
	
	$datechunks = explode("/", $indatechunks[0]); 
	
	return ( $datechunks[0].' '.$months[(int)($datechunks[1])*1].' '.$datechunks[2].' '.$indatechunks[1]);
}
// TIME HH:MM
function formatHour( $indate ) {
	$datechunks = explode(" ", $indate); 
	if ( $datechunks[1]) 
		return  $datechunks[1];

	return False;
}



$myGedcom = new gedcomParser( $db );

$debugMode = NULL;
$gedfilename = $myGedcom->selectMeta('GEDCOMFILE') ;
@unlink('tmp/'.$gedfilename);
$fp = fopen('tmp/'.$gedfilename, 'a');

echo '<div style="text-align: center; margin-right:auto; margin-left:auto;width:100%">';
echo '<a href="phputil/gedcomexport_download.php?file=../tmp/'.$gedfilename.'">'.$gedfilename.'</a>';
echo '</div>';
echo '<hr>';
echo '<style>    table#gedcomtable tr:nth-child(even) { background-color:#F0FFF0;  tr:nth-child(odd) { background-color:#EAF9EA; } </style>';
echo '<div style="margin:auto;width:100%"><tt><table border=0 id="gedcomtable" style="margin-left: auto; margin-right: auto;">';

// -------------------------------------------------
echoGedcom( $fp, $debugMode, 0, null,'HEAD', null );
echoGedcom( $fp, $debugMode, 1, null,'SOUR', $myGedcom->selectMeta('GEDCOMSOUR') );
echoGedcom( $fp, $debugMode, 2, null,'VERS', $myGedcom->selectMeta('GEDCOMSOURVERS') );
echoGedcom( $fp, $debugMode, 2, null,'NAME', $myGedcom->selectMeta('GEDCOMSOURNAME') );
echoGedcom( $fp, $debugMode, 1, null,'DATE', trim($myGedcom->selectMeta('GEDCOMDATE'))==''?strtoupper(date("d M Y")):formatDate($myGedcom->selectMeta('GEDCOMDATE')) );
echoGedcom( $fp, $debugMode, 2, null,'TIME', trim($myGedcom->selectMeta('GEDCOMDATE'))==''?strtoupper(date("H:m")):formatHour($myGedcom->selectMeta('GEDCOMDATE')) );
echoGedcom( $fp, $debugMode, 1, null,'CHAR', 'UTF-8' );
echoGedcom( $fp, $debugMode, 1, null,'FILE', $gedfilename );	
echoGedcom( $fp, $debugMode, 1, null,'GEDC', null );
echoGedcom( $fp, $debugMode, 2, null,'FORM', 'LINEAGE-LINKED' );
echoGedcom( $fp, $debugMode, 2, null,'VERS', '5.5.1' );
echoGedcom( $fp, $debugMode, 1, null,'SUBM', '@SUBM@' ); // pt vers Auteur
echoGedcom( $fp, $debugMode, 0, '@SUBM@', 'SUBM', null );
echoGedcom( $fp, $debugMode, 1, null,'NAME', $myGedcom->selectMeta('GEDCOMAUT') );

// --------------------------------------
$indiResults = $myGedcom->selectAllINDI();
if ($indiResults === false) { echo "Erreur : ".$myGedcom->lasterror."<br>"; }
foreach($indiResults as $indikey=>$indival) {
	
	echoGedcom( $fp, $debugMode, 0, '@I'.$indival['id'].'@','INDI', null );
	echoGedcom( $fp, $debugMode, 1, null,'NAME', $indival['name'] ); 	 
	if ($indival['givenname'] ) echoGedcom( $fp, $debugMode, 2, null,'GIVN', $indival['givenname'] ); // Prénom
	if ($indival['lastname'] ) echoGedcom( $fp, $debugMode, 2, null,'SURN', $indival['lastname'] ); // Nom de famille
	if ($indival['surname'] ) echoGedcom( $fp, $debugMode, 2, null,'NICK', $indival['surname'] ); // surnom
	if ($indival['firstnameprefix'] ) echoGedcom( $fp, $debugMode, 2, null,'NPFX', $indival['firstnameprefix'] ); // Docteur, Général, Monseigneur
	if ($indival['lastnamesuffix'] ) echoGedcom( $fp, $debugMode, 2, null,'NSFX', $indival['lastnamesuffix'] ); // 	Jr

	echoGedcom( $fp, $debugMode, 1, null,'SEX', $indival['sex'] );

	$indiEventResults = $myGedcom->selectIndiEventDate( $indival['id'] );	
	
	foreach ( $indiEventResults as $indieventKey => $indiEvent ) {
		if ($indiEvent['date_begin']) {
			echoGedcom( $fp, $debugMode, 1, null,$indiEvent['code'], null );
			echoGedcom( $fp, $debugMode, 2, null,'DATE', formatDate($indiEvent['date_begin']));
			$hour_begin = formatHour($indiEvent['date_begin']);
			//if ($hour_begin)
			//	echoGedcom( $fp, $debugMode, 3, null,'TIME', $hour_begin);		
		}

		if ( 
			$indiEvent['code'][0] != '_' 			
		)
		{
			//echoGedcom( $fp, $debugMode, 1, null, $indiEvent['code'], null );				
			$eventPlace = $myGedcom->selectIndiEventPlace( $indival['id'], $indiEvent['code']);	
			if ( $eventPlace ) 			
			{
				echoGedcom( $fp, $debugMode, 2, null,'PLAC', $eventPlace['plac'] );		
				if ($eventPlace['gpslat'] and $eventPlace['gpslon']) {
					echoGedcom( $fp, $debugMode, 3, null,'MAP', null );	
					echoGedcom( $fp, $debugMode, 4, null,'LATI', $eventPlace['gpslat'] );	
					echoGedcom( $fp, $debugMode, 4, null,'LONG', $eventPlace['gpslon'] );				
				}
			}
		}
		
		$eventSources = $myGedcom->selectEventSource( $indiEvent['id'] );
		if ($eventSources) {			
			foreach ($eventSources as $eventSourceKey => $eventSourceValue) {
				echoGedcom( $fp, $debugMode, 2, null, 'SOUR', '@S'.$eventSourceValue['id'].'@' );	
				
				if ($eventSourceValue['description']) {
					echoGedcom( $fp, $debugMode, 3, null, 'DATA', null);	
					echoGedcom( $fp, $debugMode, 4, null, 'TEXT', $eventSourceValue['description'] );				
				}
				if ($eventSourceValue['page'])
					echoGedcom( $fp, $debugMode, 3, null, 'PAGE', $eventSourceValue['page'] );				
				if ($eventSourceValue['datecreated']) {
					echoGedcom( $fp, $debugMode, 2, null,'CHAN', null );
					echoGedcom( $fp, $debugMode, 3, null,'DATE', formatDate($eventSourceValue['datecreated']) );
					if (formatHour($eventSourceValue['datecreated'])) 
						echoGedcom( $fp, $debugMode, 4, null,'TIME', formatHour($eventSourceValue['datecreated']) );				
				}
				echoGedcom( $fp, $debugMode, 3, null, 'QUAY', $eventSourceValue['quality'] );	
			}		
		}
	}			
	
	$indiFams = $myGedcom->selectIndiFAMS( $indival['id'] );	
	if ($indiFams) echoGedcom( $fp, $debugMode, 1, null, 'FAMS', '@F'.$indiFams.'@' ); // famille de son couple (pointeur vers famille @F3@)
	$indiMotherId = $myGedcom->selectIndiParents( $indival['id'] );
	$indiMotherId = $indiMotherId[0]['person_2_id'];
	$indiFams = $myGedcom->selectIndiFAMS( $indiMotherId);		
	if ($indiFams) echoGedcom( $fp, $debugMode, 1, null, 'FAMC', '@F'.$indiFams.'@' ); // famille de ses parents (pointeur vers famille @F1@)
	
	if ($indival['datecreated']) {
		echoGedcom( $fp, $debugMode, 1, null,'CHAN', null );
		echoGedcom( $fp, $debugMode, 2, null,'DATE', formatDate($indival['datecreated']));
	}	
}

// -------------------------------------
$fam0Results = $myGedcom->selectAllFAM( 'FAM0'); // Mariage, union ...
if ($fam0Results === false) { echo "Erreur : ".$myGedcom->lasterror."<br>"; }
foreach($fam0Results as $famkey=>$famval) {
	echoGedcom( $fp, $debugMode, 0, '@F'.$famval['id'].'@', 'FAM', null );
	echoGedcom( $fp, $debugMode, 1, null, 'HUSB', '@I'.$famval['hid'].'@' );
	echoGedcom( $fp, $debugMode, 1, null, 'WIFE', '@I'.$famval['wid'].'@' );
	echoGedcom( $fp, $debugMode, 1, null, $famval['code'], null );  // MARR, UNION ...

	$marDateEvent = $myGedcom->selectEventDate( $famval['id'], $famval['code'] );
	if ($marDateEvent['date_begin']) {
		echoGedcom( $fp, $debugMode, 2, null,'DATE', formatDate($marDateEvent['date_begin'])); // HOUR not allowed
	}	
	
	$eventPlace = $myGedcom->selectEventPlace( $famval['id'], $famval['code'] );
	if ($eventPlace) {
		echoGedcom( $fp, $debugMode, 2, null,'PLAC', $eventPlace['plac'] );	
		if ($eventPlace['gpslat'] and $eventPlace['gpslon']) {
			echoGedcom( $fp, $debugMode, 3, null,'MAP', null );	
			echoGedcom( $fp, $debugMode, 4, null,'LATI', $eventPlace['gpslat'] );	
			echoGedcom( $fp, $debugMode, 4, null,'LONG', $eventPlace['gpslon'] );				
		}
	}
	
	$famchildResults = $myGedcom->selectFAMCHILD( $famval['wid'] ); // ou $famval['hid']
	if ($famchildResults === false) { echo "Erreur : ".$myGedcom->lasterror."<br>"; }
	foreach($famchildResults as $famchildkey=>$famchildval) {
		echoGedcom( $fp, $debugMode, 1, null, 'CHIL', '@I'.$famchildval['id'].'@' );
	}
	
	// Evenements suite au mariage, union : divorce, séparation ...
	$fam1Results = $myGedcom->selectAllFAM1( 'FAM1' , $famval['wid'] ); // Mariage, union ...
	if ($fam1Results === false) { echo "Erreur : ".$myGedcom->lasterror."<br>"; }
	foreach($fam1Results as $fam1key=>$fam1val) {
		echoGedcom( $fp, $debugMode, 1, null, $fam1val['code'], null );  
		$marDateEvent = $myGedcom->selectEventDate( $fam1val['id'], $fam1val['code'] );
		if ($marDateEvent['date_begin']) {
			echoGedcom( $fp, $debugMode, 2, null,'DATE', formatDate($marDateEvent['date_begin'])); // HOUR not allowed
		}	
		
		$eventPlace = $myGedcom->selectEventPlace( $fam1val['id'], $fam1val['code'] );
		if ($eventPlace) {
			echoGedcom( $fp, $debugMode, 2, null,'PLAC', $eventPlace['plac'] );	
			if ($eventPlace['gpslat'] and $eventPlace['gpslon']) {
				echoGedcom( $fp, $debugMode, 3, null,'MAP', null);	
				echoGedcom( $fp, $debugMode, 4, null,'LATI', $eventPlace['gpslat'] );	
				echoGedcom( $fp, $debugMode, 4, null,'LONG', $eventPlace['gpslon'] );				
			}
		}
		
	}	
	
	if ($famval['datecreated']) {
		echoGedcom( $fp, $debugMode, 1, null,'CHAN', null );
		echoGedcom( $fp, $debugMode, 2, null,'DATE', formatDate($famval['datecreated']));
	}	
}

// -------------------------------------------
// --- SOURCES
/*2 SOUR @SOURCE1@
3 PAGE 42
3 DATA
4 DATE 31 DEC 1900
4 TEXT Some death source text.
3 QUAY 3
3 NOTE A death source note.
* */
// -------------------------------------------
$sourceResults = $myGedcom->selectAllSOURCE();
if ($sourceResults === false) { echo "Erreur : ".$myGedcom->lasterror."<br>"; }
foreach($sourceResults as $sourcekey=>$sourceval) {
	echoGedcom( $fp, $debugMode, 0, '@S'.$sourceval['id'].'@', 'SOUR', null );
	
	echoGedcom( $fp, $debugMode, 1, null,  'TITL', $sourceval['name'] );
	if ($sourceval['description'])
		echoGedcom( $fp, $debugMode, 1, null, 'TEXT', $sourceval['description'] );
	//if ($sourceval['quality'])
		//echoGedcom( $fp, $debugMode, 2, null, 'QUAY', $sourceval['quality'] );				
	if ($sourceval['datecreated']) {
		echoGedcom( $fp, $debugMode, 1, null,'CHAN', null );
		echoGedcom( $fp, $debugMode, 2, null,'DATE', formatDate($sourceval['datecreated']) );
		if (formatHour($sourceval['datecreated'])) 
			echoGedcom( $fp, $debugMode, 3, null,'TIME', formatHour($sourceval['datecreated']) );
	}	
					
	/*if ($sourceval['page'])
		echoGedcom( $fp, $debugMode, 1, null, 'PAGE', $sourceval['page'] );				
	// -> level 3(2)  DATA
	echoGedcom( $fp, $debugMode, 1, null, 'DATA', null );		
	echoGedcom( $fp, $debugMode, 2, null,  'DATE', formatDate($sourceval['date_created'])); 	
	*/
			
	if ($sourceval['depot_id'])
		echoGedcom( $fp, $debugMode, 1, null, 'REPO', '@R'.$sourceval['depot_id'].'@' );
		
}

// -------------------------------------------
// --- MEDIAS / OBJECTS
// -------------------------------------------
$mediaResults = $myGedcom->selectAllOBJ();
if ($mediaResults === false) { echo "Erreur : ".$myGedcom->lasterror."<br>"; }

foreach($mediaResults as $mediakey=>$mediaval) {
	echoGedcom( $fp, $debugMode, 0, '@M'.$mediaval['id'].'@', 'OBJE', null );
	
	echoGedcom( $fp, $debugMode, 1, null, 'FILE', basename($mediaval['url'])==''?$mediaval['name']:basename($mediaval['url']) );
			
	echoGedcom( $fp, $debugMode, 2, null, 'TITL', $mediaval['name'] );	
		
	echoGedcom( $fp, $debugMode, 2, null, 'FORM', $mediaval['code'] );

	if ($mediaval['description']) 
		echoGedcom( $fp, $debugMode, 1, null,'NOTE', formatDate($mediaval['description']));
}

// -------------------------------------------
// --- DEPOTS
// -------------------------------------------
$repoResults = $myGedcom->selectAllREPO();
if ($repoResults === false) { echo "Erreur : ".$myGedcom->lasterror."<br>"; }
foreach($repoResults as $repokey=>$repoval) {
	echoGedcom( $fp, $debugMode, 0, '@R'.$repoval['id'].'@', 'REPO', null );
	echoGedcom( $fp, $debugMode, 1, null, 'NAME', $repoval['name'] );
	if ($repoval['code']) echoGedcom( $fp, $debugMode, 1, null, 'REFN', $repoval['code'] );
	if ($repoval['adress_1']) echoGedcom( $fp, $debugMode, 1, null, 'ADDR', $repoval['adress_1'] );
	if ($repoval['adress_2']) echoGedcom( $fp, $debugMode, 2, null, 'ADR1', $repoval['adress_2'] );
	if ($repoval['zip']) echoGedcom( $fp, $debugMode, 2, null, 'POST', $repoval['zip'] );
	if ($repoval['city']) echoGedcom( $fp, $debugMode, 2, null, 'CITY', $repoval['city'] );
	if ($repoval['country']) echoGedcom( $fp, $debugMode, 2, null, 'CTRY', $repoval['country'] );
	
}

echoGedcom( $fp, $debugMode, 0, null, 'TRLR', null );

fclose($fp);

echo '</table></tt></div>';
?>

